var _interopRequireDefault=require("@babel/runtime/helpers/interopRequireDefault");Object.defineProperty(exports,"__esModule",{value:true});exports.checkIfTemplateInstalled=exports.applyLocalTemplate=exports.applyTemplate=exports.getTemplateOptions=exports.addTemplate=exports.listTemplates=void 0;var _chalk=_interopRequireDefault(require("chalk"));
var _fs=_interopRequireDefault(require("fs"));
var _path=_interopRequireDefault(require("path"));
var _deepmerge=_interopRequireDefault(require("deepmerge"));
var _constants=require("../constants");
var _exec=require("../systemTools/exec");
var _fileutils=require("../systemTools/fileutils");




var _common=require("../common");
var _pluginTools=require("../pluginTools");
var _prompt=require("../systemTools/prompt");
var _projectParser=require("../projectTools/projectParser");
var _configParser=require("../configTools/configParser");

var _templates=require("../../renativeTemplates/templates.json");

var listTemplates=function listTemplates(c){return new Promise(function(resolve,reject){
(0,_common.logTask)('listTemplates');
var opts=(0,_prompt.generateOptions)(_templates.templates);
console.log(opts.asString);
resolve();
});};exports.listTemplates=listTemplates;

var addTemplate=function addTemplate(c){return new Promise(function(resolve,reject){
(0,_common.logTask)('addTemplate');var
maxErrorLength=c.program.maxErrorLength;

(0,_exec.executeAsync)('npm install renative-template-hello-world --save-dev',{maxErrorLength:maxErrorLength}).
then(function(){
resolve();
}).
catch(function(error){return(0,_common.logError)(error);});
});};exports.addTemplate=addTemplate;

var checkIfTemplateInstalled=function checkIfTemplateInstalled(c){return new Promise(function(resolve,reject){
(0,_common.logTask)('checkIfTemplateInstalled');
if(!c.buildConfig.defaults){
(0,_common.logWarning)("Your "+_chalk.default.white(c.paths.project.config)+" does not contain "+_chalk.default.white('defaultProjectConfigs')+" object. ReNative will skip template generation");
resolve();
return;
}

var templateName=c.buildConfig.defaults.template;
if(!templateName){
templateName='renative-template-hello-world';
(0,_common.logWarning)("You're missing template name in your "+_chalk.default.white(c.paths.project.config)+". ReNative will add default "+_chalk.default.white(templateName)+" for you");
c.buildConfig.defaults.template=templateName;
_fs.default.writeFileSync(c.paths.project.config,JSON.stringify(c.files.project.config,null,2));
}

c.paths.templateFolder=_path.default.join(c.paths.project.nodeModulesDir,templateName);
if(!_fs.default.existsSync(c.paths.templateFolder)){
(0,_common.logWarning)("Your "+_chalk.default.white(c.paths.templateFolder)+" template is not installed. ReNative will install it for you");

if(c.files.project.package.devDependencies){
if(!c.files.project.package.devDependencies[templateName]){
c.files.project.package.devDependencies[templateName]=c.runtime.rnvVersionRunner;
(0,_fileutils.writeObjectSync)(c.paths.project.package,c.files.project.package);
}
}



c._requiresNpmInstall=true;
}
resolve();
});};exports.checkIfTemplateInstalled=checkIfTemplateInstalled;

var applyLocalTemplate=function applyLocalTemplate(c,selectedTemplate){return new Promise(function(resolve,reject){
(0,_common.logTask)("applyLocalTemplate:"+selectedTemplate);
var currentTemplate=c.buildConfig.defaults.template;
if(selectedTemplate){
(0,_common.logTask)("applyTemplate:"+selectedTemplate);

if(currentTemplate!==selectedTemplate){
(0,_common.logWarning)("Current template "+_chalk.default.red(currentTemplate)+" will be overriden by "+_chalk.default.green(selectedTemplate));
}

var dirsToRemove=[
_path.default.join(c.paths.project.projectConfig.dir),
_path.default.join(c.paths.project.srcDir),
_path.default.join(c.paths.project.appConfigsDir)];


var filesToRemove=c.buildConfig.defaults.supportedPlatforms.map(function(p){return _path.default.join(c.paths.project.dir,"index."+p+".js");});

(0,_fileutils.removeDirsSync)(dirsToRemove);

(0,_fileutils.removeFilesSync)(filesToRemove);

c.paths.projectTemplateFolder=_path.default.join(c.paths.project.nodeModulesDir,selectedTemplate);

_applyTemplate(c).
then(function(){return(0,_projectParser.configureEntryPoints)(c);}).
then(function(){return resolve();}).
catch(function(e){return reject(e);});
}
});};exports.applyLocalTemplate=applyLocalTemplate;

var applyTemplate=function applyTemplate(c){return new Promise(function(resolve,reject){
(0,_common.logTask)('applyTemplate');
var currentTemplate=c.buildConfig.defaults.template;

if(!c.buildConfig.defaults){
reject("Your "+_constants.RENATIVE_CONFIG_NAME+" is missing defaultProjectConfigs object");
return;
}

c.paths.projectTemplateFolder=_path.default.join(c.paths.project.nodeModulesDir,c.buildConfig.defaults.template);

_applyTemplate(c).

then(function(){return resolve();}).
catch(function(e){return reject(e);});
});};exports.applyTemplate=applyTemplate;

var _applyTemplate=function _applyTemplate(c){return new Promise(function(resolve,reject){
(0,_common.logTask)("_applyTemplate:"+c.paths.projectTemplateFolder);

var templateConfigPath=_path.default.join(c.paths.projectTemplateFolder,_constants.RENATIVE_CONFIG_TEMPLATE_NAME);

if(!_fs.default.existsSync(templateConfigPath)){
(0,_common.logWarning)("Template "+_chalk.default.white(c.buildConfig.defaults.template)+" does not exist in your "+_chalk.default.white(c.paths.projectTemplateFolder)+". skipping");
resolve();
return;
}

var templateAppConfigsFolder=_path.default.join(c.paths.projectTemplateFolder,'appConfigs');
var templateAppConfigFolder=_fs.default.readdirSync(templateAppConfigsFolder)[0];
var templateProjectConfigFolder=_path.default.join(c.paths.projectTemplateFolder,'projectConfig');
var currentTemplate=c.files.project.config.defaults.template;
var templateConfig=JSON.parse(_fs.default.readFileSync(templateConfigPath).toString());


(0,_common.logTask)('configureProject:check src',_chalk.default.grey);
if(!_fs.default.existsSync(c.paths.project.srcDir)){
(0,_common.logInfo)("Looks like your src folder "+_chalk.default.white(c.paths.project.srcDir)+" is missing! Let's create one for you.");
(0,_fileutils.copyFolderContentsRecursiveSync)(_path.default.join(c.paths.projectTemplateFolder,'src'),c.paths.project.srcDir);
}


(0,_common.logTask)('configureProject:check appConfigs',_chalk.default.grey);

if(!_fs.default.existsSync(c.paths.project.appConfigsDir)){
(0,_common.logInfo)("Looks like your appConfig folder "+
_chalk.default.white(
c.paths.project.appConfigsDir)+" is missing! Let's create sample config for you.");




(0,_fileutils.copyFolderContentsRecursiveSync)(templateAppConfigsFolder,c.paths.project.appConfigsDir);

var appConfigIds=(0,_configParser.listAppConfigsFoldersSync)(c);


try{var _c$files$project,_c$files$project$defa;
appConfigIds.forEach(function(v){var _c$files$project$conf,_c$files$project$conf2,_c$files$project$conf3,_c$files$project$conf4;
var appConfigPath=_path.default.join(c.paths.project.appConfigsDir,v,_constants.RENATIVE_CONFIG_NAME);
var appConfig=(0,_fileutils.readObjectSync)(appConfigPath);
appConfig.common=appConfig.common||{};
appConfig.common.title=(_c$files$project$conf=c.files.project.config)==null?void 0:(_c$files$project$conf2=_c$files$project$conf.defaults)==null?void 0:_c$files$project$conf2.title;
appConfig.common.id=(_c$files$project$conf3=c.files.project.config)==null?void 0:(_c$files$project$conf4=_c$files$project$conf3.defaults)==null?void 0:_c$files$project$conf4.id;

(0,_fileutils.writeObjectSync)(appConfigPath,appConfig);
});

var supPlats=(_c$files$project=c.files.project)==null?void 0:(_c$files$project$defa=_c$files$project.defaults)==null?void 0:_c$files$project$defa.supportedPlatforms;

if(supPlats){
for(var pk in appConfig.platforms){
if(!supPlats.includes(pk)){
delete appConfig.platforms[pk];
}
}
}
}catch(e){
(0,_common.logError)(e);
}
}


(0,_common.logTask)('configureProject:check projectConfigs',_chalk.default.grey);
if(!_fs.default.existsSync(c.paths.project.projectConfig.dir)){
(0,_common.logInfo)("Looks like your projectConfig folder "+
_chalk.default.white(c.paths.project.projectConfig.dir)+" is missing! Let's create one for you.");

(0,_fileutils.copyFolderContentsRecursiveSync)(templateProjectConfigFolder,c.paths.project.projectConfig.dir);
}


(0,_common.logTask)('configureProject:check renative.json',_chalk.default.grey);
if(!c.runtime.isWrapper){
if(!c.files.project.config.currentTemplate){
(0,_common.logWarning)("Looks like your "+
c.paths.project.config+" need to be updated with "+templateConfigPath);

var mergedObj=(0,_fileutils.mergeObjects)(c,c.files.project.config,templateConfig,false,true);
c.files.project.config.currentTemplate=currentTemplate;
(0,_fileutils.writeObjectSync)(c.paths.project.config,mergedObj);
}
}else{
if(templateConfig.plugins.renative){
templateConfig.plugins.renative=(0,_pluginTools.getLocalRenativePlugin)();
}
(0,_fileutils.writeObjectSync)(c.paths.project.configLocal,templateConfig);
}

(0,_configParser.setAppConfig)(c,c.runtime.appId);

resolve();
});};

var getTemplateOptions=function getTemplateOptions(){return(0,_prompt.generateOptions)(_templates.templates);};exports.getTemplateOptions=getTemplateOptions;